# Interactions

https://docs.aws.amazon.com/connect/latest/APIReference/interactions.html

Actions with side effects that don't require a contact or participant. Generally work in every circumstance.

## Implementation Status

| Block | Status | Notes |
|-------|--------|-------|
| AssociateContactToCustomerProfile | Not Implemented | |
| CreateCallbackContact | Implemented | Basic implementation |
| CreateCustomerProfile | Not Implemented | |
| GetCalculatedAttributesForCustomerProfile | Not Implemented | |
| GetCustomerProfile | Not Implemented | |
| GetCustomerProfileObject | Not Implemented | |
| InvokeLambdaFunction | Implemented | Basic implementation |
| UpdateCustomerProfile | Not Implemented | |

## Implemented: 2/8
